#
# spec file for package python-yq
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-yq
Version:        2.10.0
Release:        lp152.1.1
Summary:        Command-line YAML processor - jq wrapper for YAML documents
License:        Apache-2.0
URL:            https://github.com/kislyuk/yq
Source:         https://files.pythonhosted.org/packages/source/y/yq/yq-%{version}.tar.gz
Patch0:         pyaml53.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       jq
Requires:       python-PyYAML >= 3.11
Requires:       python-argcomplete >= 1.8.1
Requires:       python-setuptools
Requires:       python-toml >= 0.9.4
Requires:       python-xmltodict >= 0.11.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML >= 3.11}
BuildRequires:  %{python_module argcomplete >= 1.8.1}
BuildRequires:  %{python_module toml >= 0.9.4}
BuildRequires:  %{python_module xmltodict >= 0.11.0}
BuildRequires:  jq
# /SECTION
%python_subpackages

%description
yq: Command-line YAML processor - jq wrapper for YAML documents

%prep
%setup -q -n yq-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/yq
%python_clone -a %{buildroot}%{_bindir}/xq
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative yq
%python_install_alternative xq

%postun
%python_uninstall_alternative yq
%python_uninstall_alternative xq

%check
export LANG=en_US.UTF-8
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python test/test.py -v

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/yq
%python_alternative %{_bindir}/xq
%{python_sitelib}/*

%changelog
* Thu Mar  5 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.10.0:
  * Add support for in-place editing (yq -yi)
  * Add argcomplete integration
  * Docs: Migrate from RTD to gh-pages
  * Add -Y/--yaml-roundtrip for preserving YAML styles and tags
- Add patch to work with new PyYAML:
  * pyaml53.patch
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.8.1:
  * Filter out -C and separate commingled yq and jq short options
  * Set default block sequence indentation to 2 spaces, –indentless for 0
  * Make main body of yq callable as a library function
  * Test and release infrastructure updates
* Tue May 21 2019 John Vandenberg <jayvdb@gmail.com>
- Add runtime dependency jq
- Set LANG in %%check to make tests pass on Leap builds
* Wed Mar 27 2019 Matej Cepl <mcepl@suse.com>
- Run test suite at least for Python 3
* Tue Mar 26 2019 pgajdos@suse.com
- version update to 2.7.2
  * xq: Introduce –xml-dtd and –xml-root.
  * TOML support is optional and experimental
  * TOML support with the tq executable entry point.
  * Disallow argparse abbreviated options.
  * Parse unrecognized tags instead of dropping them.
  * Ignore unrecognized YAML tags instead of crashing.
  * xq -x: Raise understandable error on non-dict conversion failure.
  * Support XML parsing with xmltodict.
  * Fix for the –from-file/-f argument: Re-route jq_filter to files
    when using –from-file.
  * Parse and pass multiple positional-consuming jq args.
  * Support jq arguments that consume subsequent positionals.
  * Support bare YAML dates and times.
- package LICENSE
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Dec 20 2017 tbechtold@suse.com
- Initial packaging (version 2.3.3)
